You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by ch...@apache.org on 2005/10/26 06:33:01 UTC

svn commit: r328554 [1/6] - in /webservices/axis2/trunk/java: modules/codegen/src/org/apache/axis2/databinding/extensions/ modules/codegen/src/org/apache/axis2/databinding/extensions/XMLBeans/ modules/codegen/src/org/apache/axis2/rpc/ modules/codegen/s...

Author: chinthaka
Date: Tue Oct 25 21:29:17 2005
New Revision: 328554

URL: http://svn.apache.org/viewcvs?rev=328554&view=rev
Log:
Refactoring 
s/ServiceDescription/AxisService/
s/OperationDescription/AxisOperation/
s/ServiceGroupDescription/AxisServiceGroup/

Added:
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java
      - copied, changed from r328531, webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperationFactory.java
      - copied, changed from r328531, webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescriptionFactory.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisService.java
      - copied, changed from r328531, webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisServiceGroup.java
      - copied, changed from r328531, webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceGroupDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOnlyAxisOperation.java
      - copied, changed from r328531, webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOnlyOperationDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOutAxisOperation.java
      - copied, changed from r328531, webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOutOperationDescrition.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OutInAxisOperation.java
      - copied, changed from r328531, webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OutInOperationDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OutOnlyAxisOperation.java
      - copied, changed from r328531, webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OutOnlyOperationDescription.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/AxisServiceBuilderTest.java   (contents, props changed)
      - copied, changed from r328523, webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/ServiceDescriptionBuilderTest.java
Removed:
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOnlyOperationDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOutOperationDescrition.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescriptionFactory.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OutInOperationDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OutOnlyOperationDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceGroupDescription.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/ServiceDescriptionBuilderTest.java
Modified:
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/SchemaUtility.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/XMLBeans/XMLBeansSchemaUtility.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/RPCInOutMessageReceiver.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/client/RPCCall.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/receivers/RPCMessageReceiver.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/InterfaceImplementationTemplate.xsl
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/LocalTestClassTemplate.xsl
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/MessageReceiverTemplate.xsl
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/SkeletonTemplate.xsl
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestClassTemplate.xsl
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestSkeletonImplTemplate.xsl
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/rpc/SimpleTest.java
    webservices/axis2/trunk/java/modules/common/src/org/apache/axis2/i18n/resource.properties
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/InstanceDispatcher.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/Call.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/InOnlyMEPClient.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/InOutMEPClient.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/MEPClient.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/MessageSender.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/Stub.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/TwoWayTransportBasedSender.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/ConfigurationContext.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/ConfigurationContextFactory.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/MessageContext.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/OperationContext.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/OperationContextFactory.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/ServiceContext.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/ServiceGroupContext.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DeploymentEngine.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ModuleBuilder.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ServiceBuilder.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ServiceGroupBuilder.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/repository/util/ArchiveFileData.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/repository/util/ArchiveReader.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/util/PhasesInfo.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisDescWSDLComponentFactory.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AbstractDispatcher.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AddressingBasedDispatcher.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfiguration.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfigurationImpl.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisEngine.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisEvent.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/DispatchingChecker.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/RequestURIBasedDispatcher.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/SOAPActionBasedDispatcher.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/SOAPMessageBodyBasedDispatcher.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/phaseresolver/PhaseResolver.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/receivers/AbstractInOutAsyncMessageReceiver.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/receivers/AbstractInOutSyncMessageReceiver.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/receivers/AbstractMessageReceiver.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/receivers/AbstractRobustInMessageReceiver.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/receivers/RawXMLINOnlyMessageReceiver.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/receivers/RawXMLINOutMessageReceiver.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/transport/http/ListingAgent.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/util/Utils.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/context/ContextHierarchyTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/context/ContextSerailzationWithEngine.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/context/ContextSerializationTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/context/OperationContextTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/BadServiceXMLTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/BuildERWithDeploymentTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/SameServiceAddingTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/ServiceGroupTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/description/RegistryTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/AbstractEngineTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/EnginePausingTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/EngineWithoutPhaseResolvingTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/MessageContextTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/ModuleConfigTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/ModuleEngageTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/ParamterAddTest.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/ParamterLocked.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/transport/tcp/TCPTransportTest.java
    webservices/axis2/trunk/java/modules/core/webapp/EngageToServiceGroup.jsp
    webservices/axis2/trunk/java/modules/core/webapp/HappyAxis.jsp
    webservices/axis2/trunk/java/modules/core/webapp/LeftFrame.jsp
    webservices/axis2/trunk/java/modules/core/webapp/ListServiceGroup.jsp
    webservices/axis2/trunk/java/modules/core/webapp/RemoveService.jsp
    webservices/axis2/trunk/java/modules/core/webapp/SelectService.jsp
    webservices/axis2/trunk/java/modules/core/webapp/ServiceParaEdit.jsp
    webservices/axis2/trunk/java/modules/core/webapp/ViewServiceHandlers.jsp
    webservices/axis2/trunk/java/modules/core/webapp/enaggingtoanopeartion.jsp
    webservices/axis2/trunk/java/modules/core/webapp/engagingglobally.jsp
    webservices/axis2/trunk/java/modules/core/webapp/engagingtoaservice.jsp
    webservices/axis2/trunk/java/modules/core/webapp/globalModules.jsp
    webservices/axis2/trunk/java/modules/core/webapp/happy_axis.jsp
    webservices/axis2/trunk/java/modules/core/webapp/listGroupService.jsp
    webservices/axis2/trunk/java/modules/core/webapp/listService.jsp
    webservices/axis2/trunk/java/modules/core/webapp/listServices.jsp
    webservices/axis2/trunk/java/modules/core/webapp/listSingleService.jsp
    webservices/axis2/trunk/java/modules/core/webapp/upload.jsp
    webservices/axis2/trunk/java/modules/integration/src/org/apache/axis2/interop/whitemesa/round1/Round1Client.java
    webservices/axis2/trunk/java/modules/integration/src/org/apache/axis2/interop/whitemesa/round2/SunRound2Client.java
    webservices/axis2/trunk/java/modules/integration/src/org/apache/axis2/interop/whitemesa/round3/SunRound3Client.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/CharctersetEncodingTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/CommonsHTTPEchoRawXMLTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/EchoRawXMLChunckedTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/EchoRawXMLLoadTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/EchoRawXMLMultipleTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/EchoRawXMLOnTwoChannelsSyncTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/EchoRawXMLOnTwoChannelsTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/EchoRawXMLTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/HandlerFailureTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/MessageContextInjectionTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/MessageWithServerTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/OneWayRawXMLTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/SOAPversionTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/ServiceDispatchingTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/ServiceGroupContextTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/ThreadingTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/engine/util/MyInOutMEPClient.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/groovy/GroovyServiceTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/integration/UtilServer.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/integration/UtilsTCPServer.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mail/MailCharSetEncodingTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mail/MailOneWayRawXMLTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mail/MailRequestResponseRawXMLTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mail/MailetRequestResponceRawXMLTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mtom/EchoRawMTOMCommonsChunkingTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mtom/EchoRawMTOMFaultReportTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mtom/EchoRawMTOMFileCacheLoadTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mtom/EchoRawMTOMFileCacheTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mtom/EchoRawMTOMLoadTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mtom/EchoRawMTOMTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/mtom/EchoRawMTOMToBase64Test.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/processingModel/SoapProcessingModelTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/rest/HttpGetRESTBasedTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/rest/RESTBasedEchoRawXMLTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/rpc/MultirefTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/rpc/RPCCallTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/swa/EchoRawSwATest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/tcp/TCPEchoRawXMLTest.java
    webservices/axis2/trunk/java/modules/integration/test/org/apache/axis2/tcp/TCPTwoChannelEchoRawXMLTest.java
    webservices/axis2/trunk/java/modules/samples/src/sample/amazon/search/AsynchronousClient.java
    webservices/axis2/trunk/java/modules/samples/src/sample/google/search/AsynchronousClient.java
    webservices/axis2/trunk/java/modules/samples/src/sample/groovy/GroovyReceiver.java
    webservices/axis2/trunk/java/modules/samples/xdocs/amazonSearch/AmazonSearch.htm
    webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/handler/WSDoAllHandler.java
    webservices/axis2/trunk/java/modules/wsdl/src/org/apache/axis2/wsdl/builder/WOMBuilder.java
    webservices/axis2/trunk/java/modules/wsdl/src/org/apache/axis2/wsdl/builder/WSDL2ToWOMBuilder.java
    webservices/axis2/trunk/java/modules/wsdl/src/org/apache/axis2/wsdl/builder/wsdl4j/WSDL1ToWOMBuilder.java
    webservices/axis2/trunk/java/modules/wsdl/test/org/apache/axis2/wsdl/writer/WOMInputOutputTest.java
    webservices/axis2/trunk/java/xdocs/mail-transport.html
    webservices/axis2/trunk/java/xdocs/migration.html

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/SchemaUtility.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/SchemaUtility.java?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/SchemaUtility.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/SchemaUtility.java Tue Oct 25 21:29:17 2005
@@ -1,7 +1,7 @@
 package org.apache.axis2.databinding.extensions;
 
 import org.apache.axis2.AxisFault;
-import org.apache.axis2.description.ServiceDescription;
+import org.apache.axis2.description.AxisService;
 
 import javax.wsdl.Definition;
 
@@ -35,29 +35,29 @@
      * to code gen the skeletons. This method will check, any how, to see whether the generated
      * code was generated by him and reurns appropriate boolean depending on the result.
      *
-     * @param serviceDescription
+     * @param axisService
      * @return boolean 
      */
 
-    public boolean isRelevant(ServiceDescription serviceDescription) throws AxisFault;
+    public boolean isRelevant(AxisService axisService) throws AxisFault;
 
     /**
      * isRelevant() must be called before calling this method.
      * This will fill the given definition element with the information that can be extracted from
      * the deployed service archive
-     * @param serviceDescription
+     * @param axisService
      * @throws AxisFault
      */
-    public void fillInformationFromServiceDescription(ServiceDescription serviceDescription, Definition definition) throws AxisFault;
+    public void fillInformationFromAxisService(AxisService axisService, Definition definition) throws AxisFault;
 
     /**
      * isRelevant() must be called before calling this method.
      * This will fill the given definition element with the information that can be extracted from
      * the deployed service archive
-     * @param serviceDescription
+     * @param axisService
      * @return Definition
      * @throws AxisFault
      */
-    public Definition fillInformationFromServiceDescription(ServiceDescription serviceDescription) throws AxisFault;
+    public Definition fillInformationFromAxisService(AxisService axisService) throws AxisFault;
 
 }

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/XMLBeans/XMLBeansSchemaUtility.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/XMLBeans/XMLBeansSchemaUtility.java?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/RPCInOutMessageReceiver.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/RPCInOutMessageReceiver.java Tue Oct 25 21:29:17 2005
@@ -17,11 +17,10 @@
 package org.apache.axis2.rpc;
 
 import org.apache.axis2.AxisFault;
-import org.apache.axis2.description.OperationDescription;
 import org.apache.axis2.context.MessageContext;
 import org.apache.axis2.context.OperationContext;
 import org.apache.axis2.databinding.DeserializationContext;
-import org.apache.axis2.databinding.Deserializer;
+import org.apache.axis2.description.AxisOperation;
 import org.apache.axis2.om.OMAbstractFactory;
 import org.apache.axis2.om.OMElement;
 import org.apache.axis2.receivers.AbstractInOutSyncMessageReceiver;
@@ -29,11 +28,8 @@
 import org.apache.axis2.soap.SOAPEnvelope;
 import org.apache.axis2.soap.SOAPFactory;
 
-import javax.xml.namespace.QName;
 import java.lang.reflect.Method;
-import java.util.HashMap;
 import java.util.Iterator;
-import java.util.Map;
 
 /**
  *
@@ -54,10 +50,10 @@
          * Locate method descriptor using QName or action
          */
         OperationContext oc = inMessage.getOperationContext();
-        OperationDescription description = oc.getOperationDescription();
-        RPCMethod method = (RPCMethod)description.getMetadataBag().get(RPCMETHOD_PROPERTY);
+        AxisOperation axisOperation = oc.getAxisOperation();
+        RPCMethod method = (RPCMethod)axisOperation.getMetadataBag().get(RPCMETHOD_PROPERTY);
         if (method == null) {
-            throw new AxisFault("Couldn't find RPCMethod in OperationDescription");
+            throw new AxisFault("Couldn't find RPCMethod in AxisOperation");
         }
 
         Method javaMethod = method.getJavaMethod();

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/client/RPCCall.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/client/RPCCall.java?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/client/RPCCall.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/client/RPCCall.java Tue Oct 25 21:29:17 2005
@@ -24,7 +24,7 @@
 import org.apache.axis2.clientapi.InOutMEPClient;
 import org.apache.axis2.context.MessageContext;
 import org.apache.axis2.context.ServiceContext;
-import org.apache.axis2.description.OperationDescription;
+import org.apache.axis2.description.AxisOperation;
 import org.apache.axis2.om.OMElement;
 import org.apache.axis2.soap.SOAPEnvelope;
 import org.apache.axis2.util.BeanSerializerUtil;
@@ -35,7 +35,7 @@
 public class RPCCall extends Call {
 
 
-    protected static OperationDescription operationTemplate;
+    protected static AxisOperation axisOperationTemplate;
 
     /**
      * @throws org.apache.axis2.AxisFault
@@ -76,11 +76,11 @@
      * @return Response OMElement
      */
     public OMElement invokeBlocking(QName opName, Object [] args) throws AxisFault {
-        OperationDescription opDesc =
-                serviceContext.getServiceConfig().getOperation(opName);
+        AxisOperation opDesc =
+                serviceContext.getAxisService().getOperation(opName);
         opDesc = createOpDescAndFillInFlowInformation(opDesc, opName.getLocalPart(),
                 WSDLConstants.MEP_CONSTANT_IN_OUT);
-        opDesc.setParent(serviceContext.getServiceConfig());
+        opDesc.setParent(serviceContext.getAxisService());
         MessageContext msgctx = prepareTheSOAPEnvelope(BeanSerializerUtil.getOMElement(opName, args));
 
         this.lastResponseMessage = super.invokeBlocking(opDesc, msgctx);
@@ -105,11 +105,11 @@
      */
 
     public Object[]  invokeBlocking(QName opName, Object [] args, Object [] returnTypes) throws AxisFault {
-        OperationDescription opDesc =
-                serviceContext.getServiceConfig().getOperation(opName);
+        AxisOperation opDesc =
+                serviceContext.getAxisService().getOperation(opName);
         opDesc = createOpDescAndFillInFlowInformation(opDesc, opName.getLocalPart(),
                 WSDLConstants.MEP_CONSTANT_IN_OUT);
-        opDesc.setParent(serviceContext.getServiceConfig());
+        opDesc.setParent(serviceContext.getAxisService());
         MessageContext msgctx = prepareTheSOAPEnvelope(BeanSerializerUtil.getOMElement(opName, args));
         this.lastResponseMessage = super.invokeBlocking(opDesc, msgctx);
         SOAPEnvelope resEnvelope = lastResponseMessage.getEnvelope();
@@ -131,8 +131,8 @@
             Object [] args,
             Callback callback)
             throws AxisFault {
-        OperationDescription opDesc =
-                serviceContext.getServiceConfig().getOperation(opName);
+        AxisOperation opDesc =
+                serviceContext.getAxisService().getOperation(opName);
         opDesc = createOpDescAndFillInFlowInformation(opDesc, opName.getLocalPart(), WSDLConstants.MEP_CONSTANT_IN_OUT);
         MessageContext msgctx = prepareTheSOAPEnvelope(BeanSerializerUtil.getOMElement(opName, args));
         //call the underline implementation

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/receivers/RPCMessageReceiver.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/receivers/RPCMessageReceiver.java?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/InterfaceImplementationTemplate.xsl (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/InterfaceImplementationTemplate.xsl Tue Oct 25 21:29:17 2005
@@ -1,325 +1,325 @@
-<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
-    <xsl:output method="text"/>
-    <xsl:template match="/class">
-    <xsl:variable name="interfaceName"><xsl:value-of select="@interfaceName"/></xsl:variable>
-    <xsl:variable name="package"><xsl:value-of select="@package"/></xsl:variable>
-    <xsl:variable name="callbackname"><xsl:value-of select="@callbackname"/></xsl:variable>
-    <xsl:variable name="isSync"><xsl:value-of select="@isSync"/></xsl:variable>
-    <xsl:variable name="isAsync"><xsl:value-of select="@isAsync"/></xsl:variable>
-    <xsl:variable name="dbpackage"><xsl:value-of select="@dbsupportpackage"/></xsl:variable>
-    <xsl:variable name="soapVersion"><xsl:value-of select="@soap-version"/></xsl:variable>
-    package <xsl:value-of select="$package"/>;
-
-    /*
-     *  Auto generated java implementation by the Axis code generator
-    */
-
-    public class <xsl:value-of select="@name"/> extends org.apache.axis2.clientapi.Stub implements <xsl:value-of select="$interfaceName"/>{
-        //default axis home being null forces the system to pick up the mars from the axis2 library
-        public static final String AXIS2_HOME = null;
-        protected static org.apache.axis2.description.OperationDescription[] _operations;
-
-        static{
-
-           //creating the Service
-           _service = new org.apache.axis2.description.ServiceDescription(new javax.xml.namespace.QName("<xsl:value-of select="@namespace"/>","<xsl:value-of select="@servicename"/>"));
-
-           //creating the operations
-           org.apache.axis2.description.OperationDescription __operation;
-           _operations = new org.apache.axis2.description.OutInOperationDescription[<xsl:value-of select="count(method)"/>];
-      <xsl:for-each select="method">
-           __operation = new org.apache.axis2.description.OutInOperationDescription();
-           __operation.setName(new javax.xml.namespace.QName("<xsl:value-of select="@namespace"/>", "<xsl:value-of select="@name"/>"));
-           _operations[<xsl:value-of select="position()-1"/>]=__operation;
-           _service.addOperation(__operation);
-     </xsl:for-each>
-       }
-
-       /**
-        * Constructor
-        */
-        public <xsl:value-of select="@name"/>(String axis2Home,String targetEndpoint) throws java.lang.Exception {
-			this.toEPR = new org.apache.axis2.addressing.EndpointReference(targetEndpoint);
-		    //creating the configuration
-           _configurationContext = new org.apache.axis2.context.ConfigurationContextFactory().buildClientConfigurationContext(axis2Home);
-            _configurationContext.getAxisConfiguration().addService(_service);
-           _serviceContext =_service.getParent().getServiceGroupContext(_configurationContext).getServiceContext(_service.getName().getLocalPart());
-        <!--  Set the soap version depending on the binding. Default is 1.1 so don't set anything for that case-->
-        <xsl:if test="$soapVersion='1.2'">
-            //Set the soap version
-            setSOAPVersion(SOAP_12);
-        </xsl:if>
-
-
-
-        }
-
-        /**
-        * Default Constructor
-        */
-        public <xsl:value-of select="@name"/>() throws java.lang.Exception {
-		    this(AXIS2_HOME,"<xsl:value-of select="endpoint"/>" );
-	    }
-
-
-
-     <xsl:for-each select="method">
-         <xsl:variable name="outputtype"><xsl:value-of select="output/param/@type"></xsl:value-of></xsl:variable>
-         <xsl:variable name="style"><xsl:value-of select="@style"></xsl:value-of></xsl:variable>
-        <xsl:variable name="dbsupportclassname"><xsl:value-of select="@dbsupportname"></xsl:value-of></xsl:variable>
-         <xsl:variable name="soapAction"><xsl:value-of select="@soapaction"></xsl:value-of></xsl:variable>
-         <xsl:variable name="fullsupporterclassname"><xsl:value-of select="$dbpackage"/>.<xsl:value-of select="$dbsupportclassname"/></xsl:variable>
-         <xsl:variable name="mep"><xsl:value-of select="@mep"/></xsl:variable>
-
-         <!-- Code generation for the in-out mep -->
-		 <xsl:if test="$mep='http://www.w3.org/2004/08/wsdl/in-out'">
-         <xsl:if test="$isSync='1'">
-        /**
-         * Auto generated method signature
-         * @see <xsl:value-of select="$package"/>.<xsl:value-of select="$interfaceName"/>#<xsl:value-of select="@name"/>
-         <xsl:for-each select="input/param[@type!='']">
-         * @param <xsl:value-of select="@name"></xsl:value-of><xsl:text>
-         </xsl:text></xsl:for-each>
-         */
-        public <xsl:choose><xsl:when test="$outputtype=''">void</xsl:when><xsl:otherwise><xsl:value-of select="$outputtype"/></xsl:otherwise></xsl:choose>
-        <xsl:text> </xsl:text><xsl:value-of select="@name"/>(
-         <xsl:for-each select="input/param[@type!='']">
-            <xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@type"/><xsl:text> </xsl:text><xsl:value-of select="@name"/>
-         </xsl:for-each>) throws java.rmi.RemoteException{
-
-		    org.apache.axis2.clientapi.Call _call = new org.apache.axis2.clientapi.Call(_serviceContext);
-            _call.setTransportInfo(this.senderTransport,this.listenerTransport,this.useSeparateListener);
-
- 		    org.apache.axis2.context.MessageContext _messageContext = getMessageContext();
-            _call.setTo(this.toEPR);
-            _call.setSoapAction("<xsl:value-of select="$soapAction"/>");
-            <xsl:for-each select="input/param[@Action!='']">_messageContext.setWSAAction("<xsl:value-of select="@Action"/>");</xsl:for-each>
-
-             //set the properties
+<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
+    <xsl:output method="text"/>
+    <xsl:template match="/class">
+    <xsl:variable name="interfaceName"><xsl:value-of select="@interfaceName"/></xsl:variable>
+    <xsl:variable name="package"><xsl:value-of select="@package"/></xsl:variable>
+    <xsl:variable name="callbackname"><xsl:value-of select="@callbackname"/></xsl:variable>
+    <xsl:variable name="isSync"><xsl:value-of select="@isSync"/></xsl:variable>
+    <xsl:variable name="isAsync"><xsl:value-of select="@isAsync"/></xsl:variable>
+    <xsl:variable name="dbpackage"><xsl:value-of select="@dbsupportpackage"/></xsl:variable>
+    <xsl:variable name="soapVersion"><xsl:value-of select="@soap-version"/></xsl:variable>
+    package <xsl:value-of select="$package"/>;
+
+    /*
+     *  Auto generated java implementation by the Axis code generator
+    */
+
+    public class <xsl:value-of select="@name"/> extends org.apache.axis2.clientapi.Stub implements <xsl:value-of select="$interfaceName"/>{
+        //default axis home being null forces the system to pick up the mars from the axis2 library
+        public static final String AXIS2_HOME = null;
+        protected static org.apache.axis2.description.AxisOperation[] _operations;
+
+        static{
+
+           //creating the Service
+           _service = new org.apache.axis2.description.AxisService(new javax.xml.namespace.QName("<xsl:value-of select="@namespace"/>","<xsl:value-of select="@servicename"/>"));
+
+           //creating the operations
+           org.apache.axis2.description.AxisOperation __operation;
+           _operations = new org.apache.axis2.description.OutInAxisOperation[<xsl:value-of select="count(method)"/>];
+      <xsl:for-each select="method">
+           __operation = new org.apache.axis2.description.OutInAxisOperation();
+           __operation.setName(new javax.xml.namespace.QName("<xsl:value-of select="@namespace"/>", "<xsl:value-of select="@name"/>"));
+           _operations[<xsl:value-of select="position()-1"/>]=__operation;
+           _service.addOperation(__operation);
+     </xsl:for-each>
+       }
+
+       /**
+        * Constructor
+        */
+        public <xsl:value-of select="@name"/>(String axis2Home,String targetEndpoint) throws java.lang.Exception {
+			this.toEPR = new org.apache.axis2.addressing.EndpointReference(targetEndpoint);
+		    //creating the configuration
+           _configurationContext = new org.apache.axis2.context.ConfigurationContextFactory().buildClientConfigurationContext(axis2Home);
+            _configurationContext.getAxisConfiguration().addService(_service);
+           _serviceContext =_service.getParent().getServiceGroupContext(_configurationContext).getServiceContext(_service.getName().getLocalPart());
+        <!--  Set the soap version depending on the binding. Default is 1.1 so don't set anything for that case-->
+        <xsl:if test="$soapVersion='1.2'">
+            //Set the soap version
+            setSOAPVersion(SOAP_12);
+        </xsl:if>
+
+
+
+        }
+
+        /**
+        * Default Constructor
+        */
+        public <xsl:value-of select="@name"/>() throws java.lang.Exception {
+		    this(AXIS2_HOME,"<xsl:value-of select="endpoint"/>" );
+	    }
+
+
+
+     <xsl:for-each select="method">
+         <xsl:variable name="outputtype"><xsl:value-of select="output/param/@type"></xsl:value-of></xsl:variable>
+         <xsl:variable name="style"><xsl:value-of select="@style"></xsl:value-of></xsl:variable>
+        <xsl:variable name="dbsupportclassname"><xsl:value-of select="@dbsupportname"></xsl:value-of></xsl:variable>
+         <xsl:variable name="soapAction"><xsl:value-of select="@soapaction"></xsl:value-of></xsl:variable>
+         <xsl:variable name="fullsupporterclassname"><xsl:value-of select="$dbpackage"/>.<xsl:value-of select="$dbsupportclassname"/></xsl:variable>
+         <xsl:variable name="mep"><xsl:value-of select="@mep"/></xsl:variable>
+
+         <!-- Code generation for the in-out mep -->
+		 <xsl:if test="$mep='http://www.w3.org/2004/08/wsdl/in-out'">
+         <xsl:if test="$isSync='1'">
+        /**
+         * Auto generated method signature
+         * @see <xsl:value-of select="$package"/>.<xsl:value-of select="$interfaceName"/>#<xsl:value-of select="@name"/>
+         <xsl:for-each select="input/param[@type!='']">
+         * @param <xsl:value-of select="@name"></xsl:value-of><xsl:text>
+         </xsl:text></xsl:for-each>
+         */
+        public <xsl:choose><xsl:when test="$outputtype=''">void</xsl:when><xsl:otherwise><xsl:value-of select="$outputtype"/></xsl:otherwise></xsl:choose>
+        <xsl:text> </xsl:text><xsl:value-of select="@name"/>(
+         <xsl:for-each select="input/param[@type!='']">
+            <xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@type"/><xsl:text> </xsl:text><xsl:value-of select="@name"/>
+         </xsl:for-each>) throws java.rmi.RemoteException{
+
+		    org.apache.axis2.clientapi.Call _call = new org.apache.axis2.clientapi.Call(_serviceContext);
+            _call.setTransportInfo(this.senderTransport,this.listenerTransport,this.useSeparateListener);
+
+ 		    org.apache.axis2.context.MessageContext _messageContext = getMessageContext();
+            _call.setTo(this.toEPR);
+            _call.setSoapAction("<xsl:value-of select="$soapAction"/>");
+            <xsl:for-each select="input/param[@Action!='']">_messageContext.setWSAAction("<xsl:value-of select="@Action"/>");</xsl:for-each>
+
+             //set the properties
             populateProperties(_call);
             populateModules(_call);
-
-            org.apache.axis2.soap.SOAPEnvelope env = null;
-            env = createEnvelope();
-            <xsl:variable name="count"><xsl:value-of select="count(input/param[@type!=''])"></xsl:value-of></xsl:variable>
-            <xsl:choose>
-            <!-- test the number of input parameters
-				  If the number of parameter is more then just run the normal test-->
-                <xsl:when test="$count>0">
-                  <xsl:choose>
-                      <xsl:when test="$style='rpc'">
-               // Style is RPC
-              setValueRPC(env,"<xsl:value-of select="@namespace"/>","<xsl:value-of select="@name"/>",
-              new String[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if>"<xsl:value-of select="@name"/>"</xsl:for-each>},
-              new Object[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@name"/></xsl:for-each>});
-                      </xsl:when>
-                      <xsl:when test="$style='doc'">
-
-               //Style is Doc.
-                <xsl:for-each select="input/param[@location='body']">
-               setValueDoc(env,<xsl:value-of select="$fullsupporterclassname"/>.toOM(<xsl:value-of select="@name"/>));
-                 </xsl:for-each>
-                 <xsl:for-each select="input/param[@location='header']">
-               setValueDoc(env,<xsl:value-of select="$fullsupporterclassname"/>.toOM(<xsl:value-of select="@name"/>),true);
-                 </xsl:for-each>
-                 </xsl:when>
-                 <xsl:otherwise>
-               //Unknown style!! No code is generated
-               throw java.lang.UnsupportedOperationException("Unknown Style");
-                      </xsl:otherwise>
-                  </xsl:choose>
-              </xsl:when>
-              <!-- No input parameters present. So generate assuming no input parameters-->
-              <xsl:otherwise>
-                   <xsl:choose>
-                   <xsl:when test="$style='rpc'">
-               //Style is RPC. No input parameters
-               setValueRPC(env,"<xsl:value-of select="@namespace"/>","<xsl:value-of select="@name"/>",null,null);
-                      </xsl:when>
-                     <xsl:when test="$style='doc'">
-               //Style is Doc. No input parameters
-               setValueDoc(env,null);
-                      </xsl:when>
-                      <xsl:otherwise>
-             //Unknown style!! No code is generated
-              throw UnsupportedOperationException("Unknown Style");
-                      </xsl:otherwise>
-                  </xsl:choose>
-             </xsl:otherwise>
-            </xsl:choose>
-
-             _messageContext.setEnvelope(env);
-             <xsl:choose>
-             <xsl:when test="$outputtype=''">
-             _call.invokeBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext);
-               return;
-              </xsl:when>
-              <xsl:otherwise>
-             //set the exception throwing status
-             _call.setExceptionToBeThrownOnSOAPFault(true);
-             org.apache.axis2.context.MessageContext  _returnMessageContext = _call.invokeBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext);
-             org.apache.axis2.soap.SOAPEnvelope _returnEnv = _returnMessageContext.getEnvelope();
-             java.lang.Object object = <xsl:value-of select="$fullsupporterclassname"/>.fromOM(getElement(_returnEnv,"<xsl:value-of select="$style"/>"),<xsl:value-of select="$outputtype"/>.class);
-             return (<xsl:value-of select="$outputtype"/>)object;
-                 </xsl:otherwise>
-             </xsl:choose>
-
-            <!-- this needs to be changed -->
-        }
-        </xsl:if>
-        <xsl:if test="$isAsync='1'">
-         /**
-         * Auto generated method signature for Asynchronous Invocations
-         * @see <xsl:value-of select="$package"/>.<xsl:value-of select="$interfaceName"/>#start<xsl:value-of select="@name"/>
-          <xsl:for-each select="input/param[@type!='']">
-         * @param <xsl:value-of select="@name"></xsl:value-of><xsl:text>
-         </xsl:text></xsl:for-each>
-         */
-        public  void start<xsl:value-of select="@name"/>(
-         <xsl:variable name="paramCount"><xsl:value-of select="count(input/param[@type!=''])"></xsl:value-of></xsl:variable>
-         <xsl:for-each select="input/param[@type!='']">
-            <xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@type"/><xsl:text> </xsl:text><xsl:value-of select="@name"></xsl:value-of></xsl:for-each>
-            <xsl:if test="$paramCount>0">,</xsl:if>final <xsl:value-of select="$package"/>.<xsl:value-of select="$callbackname"/> callback) throws java.rmi.RemoteException{
-
-             org.apache.axis2.clientapi.Call _call = new org.apache.axis2.clientapi.Call(_serviceContext);
- 		     org.apache.axis2.context.MessageContext _messageContext = getMessageContext();
-            _call.setTo(this.toEPR);
-            _call.setSoapAction("<xsl:value-of select="$soapAction"/>");
-            <xsl:for-each select="input/param[@Action!='']">_messageContext.setWSAAction("<xsl:value-of select="@Action"/>");</xsl:for-each>
-
-             org.apache.axis2.soap.SOAPEnvelope env = createEnvelope();
-             <xsl:choose>
-             <!-- There are more than 1 parameter in the input-->
-              <xsl:when test="$paramCount>0">
-              <xsl:choose>
-               <xsl:when test="$style='rpc'">
-           // Style is RPC
-           setValueRPC(env,
-            "<xsl:value-of select="@namespace"/>",
-            "<xsl:value-of select="@name"/>",
-             new String[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if>"<xsl:value-of select="@name"/>"</xsl:for-each>},
-             new Object[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@name"/></xsl:for-each>});
-                      </xsl:when>
-
-                      <xsl:when test="$style='doc'">
-           //Style is Doc
-            setValueDoc(env,<xsl:value-of select="$fullsupporterclassname"/>.toOM(<xsl:value-of select="input/param[1]/@name"/>));
-                      </xsl:when>
-                      <xsl:otherwise>
-          //Unknown style!! No code is generated
-          throw UnsupportedOperationException("Unknown Style");
-                      </xsl:otherwise>
-                  </xsl:choose>
-              </xsl:when>
-              <xsl:otherwise>
-                   <xsl:choose>
-                   <xsl:when test="$style='rpc'">
-           //Style is RPC. No input parameters
-              setValueRPC(env,
-                "<xsl:value-of select="@namespace"/>",
-                "<xsl:value-of select="@name"/>",
-                null,
-                null);
-                      </xsl:when>
-                      <!-- The follwing code is specific to XML beans-->
-                      <xsl:when test="$style='doc'">
-           //Style is Doc. No input parameters
-           setValueDoc(env,null);
-                      </xsl:when>
-                      <xsl:otherwise>
-          //Unknown style!! No code is generated
-          throw UnsupportedOperationException("Unknown Style");
-                      </xsl:otherwise>
-                  </xsl:choose>
-              </xsl:otherwise>
-            </xsl:choose>
-             _messageContext.setEnvelope(env);
-             <xsl:choose>
-             <xsl:when test="$outputtype=''">
-              //Nothing to pass as the callback!!!
-              _call.invokeNonBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext,null);
-              </xsl:when>
-              <xsl:otherwise>
-               _call.invokeNonBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext, new org.apache.axis2.clientapi.Callback(){
-                public void onComplete(org.apache.axis2.clientapi.AsyncResult result){
-
-			    java.lang.Object object = <xsl:value-of select="$fullsupporterclassname"/>.fromOM(getElement(result.getResponseEnvelope(),"<xsl:value-of select="$style"/>"),<xsl:value-of select="$outputtype"/>.class);
-                             callback.receiveResult<xsl:value-of select="@name"/>((<xsl:value-of select="$outputtype"/>)object);
-                }
-                public void reportError(java.lang.Exception e){
-                      callback.receiveError<xsl:value-of select="@name"/>(e);
-                }
-             }
-            );
-              </xsl:otherwise>
-             </xsl:choose>
-        }
-      </xsl:if>
-      <!-- End of in-out mep -->
-      </xsl:if>
-      <!-- Start of in only mep-->
-      <xsl:if test="$mep='http://www.w3.org/2004/08/wsdl/in-only'">
-      <!-- for the in only mep there is no notion of sync or async. And there is no return type also -->
-      public void <xsl:text> </xsl:text><xsl:value-of select="@name"/>(
-         <xsl:for-each select="input/param[@type!='']">
-            <xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@type"/><xsl:text> </xsl:text><xsl:value-of select="@name"/>
-         </xsl:for-each>) throws java.rmi.RemoteException{
-         org.apache.axis2.clientapi.Call _call = new org.apache.axis2.clientapi.Call(_serviceContext);
-            _call.setTransportInfo(this.senderTransport,this.listenerTransport,this.useSeparateListener);
-            
- 		    org.apache.axis2.context.MessageContext _messageContext = getMessageContext();
-            _call.setTo(this.toEPR);
-            _call.setSoapAction("<xsl:value-of select="$soapAction"/>");
-            <xsl:for-each select="input/param[@Action!='']">_messageContext.setWSAAction("<xsl:value-of select="@Action"/>");</xsl:for-each>
-
-          org.apache.axis2.soap.SOAPEnvelope env = null;
-            env = createEnvelope();
-            <xsl:choose>
-            <!-- test the number of input parameters
-				  If the number of parameter is more then just run the normal generation-->
-              <xsl:when test="count(input/param[@type!=''])>0">
-                  <xsl:choose>
-                      <xsl:when test="$style='rpc'">
-               // Style is RPC
-              setValueRPC(env,"<xsl:value-of select="@namespace"/>","<xsl:value-of select="@name"/>",
-              new String[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if>"<xsl:value-of select="@name"/>"</xsl:for-each>},
-              new Object[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@name"/></xsl:for-each>});
-                      </xsl:when>
-                      <xsl:when test="$style='doc'">
-                      <!-- for the doc lit case there can be only one element. So take the first element -->
-               //Style is Doc.
-               setValueDoc(env,<xsl:value-of select="$fullsupporterclassname"/>.toOM(<xsl:value-of select="input/param[1]/@name"/>));
-                      </xsl:when>
-                      <xsl:otherwise>
-               //Unknown style!! No code is generated
-               throw java.lang.UnsupportedOperationException("Unknown Style");
-                      </xsl:otherwise>
-                  </xsl:choose>
-              </xsl:when>
-              <!-- No input parameters present. So generate assuming no input parameters-->
-              <xsl:otherwise>
-                   <xsl:choose>
-                   <xsl:when test="$style='rpc'">
-               //Style is RPC. No input parameters
-               setValueRPC(env,"<xsl:value-of select="@namespace"/>","<xsl:value-of select="@name"/>",null,null);
-                      </xsl:when>
-                     <xsl:when test="$style='doc'">
-               //Style is Doc. No input parameters
-               setValueDoc(env,null);
-                      </xsl:when>
-                      <xsl:otherwise>
-             //Unknown style!! No code is generated
-              throw UnsupportedOperationException("Unknown Style");
-                      </xsl:otherwise>
-                  </xsl:choose>
-             </xsl:otherwise>
-            </xsl:choose>
-             _messageContext.setEnvelope(env);
-             _call.invokeBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext);
-               return;
-          }
-      </xsl:if>
-     </xsl:for-each>
-    }
-    </xsl:template>
+
+            org.apache.axis2.soap.SOAPEnvelope env = null;
+            env = createEnvelope();
+            <xsl:variable name="count"><xsl:value-of select="count(input/param[@type!=''])"></xsl:value-of></xsl:variable>
+            <xsl:choose>
+            <!-- test the number of input parameters
+				  If the number of parameter is more then just run the normal test-->
+                <xsl:when test="$count>0">
+                  <xsl:choose>
+                      <xsl:when test="$style='rpc'">
+               // Style is RPC
+              setValueRPC(env,"<xsl:value-of select="@namespace"/>","<xsl:value-of select="@name"/>",
+              new String[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if>"<xsl:value-of select="@name"/>"</xsl:for-each>},
+              new Object[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@name"/></xsl:for-each>});
+                      </xsl:when>
+                      <xsl:when test="$style='doc'">
+
+               //Style is Doc.
+                <xsl:for-each select="input/param[@location='body']">
+               setValueDoc(env,<xsl:value-of select="$fullsupporterclassname"/>.toOM(<xsl:value-of select="@name"/>));
+                 </xsl:for-each>
+                 <xsl:for-each select="input/param[@location='header']">
+               setValueDoc(env,<xsl:value-of select="$fullsupporterclassname"/>.toOM(<xsl:value-of select="@name"/>),true);
+                 </xsl:for-each>
+                 </xsl:when>
+                 <xsl:otherwise>
+               //Unknown style!! No code is generated
+               throw java.lang.UnsupportedOperationException("Unknown Style");
+                      </xsl:otherwise>
+                  </xsl:choose>
+              </xsl:when>
+              <!-- No input parameters present. So generate assuming no input parameters-->
+              <xsl:otherwise>
+                   <xsl:choose>
+                   <xsl:when test="$style='rpc'">
+               //Style is RPC. No input parameters
+               setValueRPC(env,"<xsl:value-of select="@namespace"/>","<xsl:value-of select="@name"/>",null,null);
+                      </xsl:when>
+                     <xsl:when test="$style='doc'">
+               //Style is Doc. No input parameters
+               setValueDoc(env,null);
+                      </xsl:when>
+                      <xsl:otherwise>
+             //Unknown style!! No code is generated
+              throw UnsupportedOperationException("Unknown Style");
+                      </xsl:otherwise>
+                  </xsl:choose>
+             </xsl:otherwise>
+            </xsl:choose>
+
+             _messageContext.setEnvelope(env);
+             <xsl:choose>
+             <xsl:when test="$outputtype=''">
+             _call.invokeBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext);
+               return;
+              </xsl:when>
+              <xsl:otherwise>
+             //set the exception throwing status
+             _call.setExceptionToBeThrownOnSOAPFault(true);
+             org.apache.axis2.context.MessageContext  _returnMessageContext = _call.invokeBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext);
+             org.apache.axis2.soap.SOAPEnvelope _returnEnv = _returnMessageContext.getEnvelope();
+             java.lang.Object object = <xsl:value-of select="$fullsupporterclassname"/>.fromOM(getElement(_returnEnv,"<xsl:value-of select="$style"/>"),<xsl:value-of select="$outputtype"/>.class);
+             return (<xsl:value-of select="$outputtype"/>)object;
+                 </xsl:otherwise>
+             </xsl:choose>
+
+            <!-- this needs to be changed -->
+        }
+        </xsl:if>
+        <xsl:if test="$isAsync='1'">
+         /**
+         * Auto generated method signature for Asynchronous Invocations
+         * @see <xsl:value-of select="$package"/>.<xsl:value-of select="$interfaceName"/>#start<xsl:value-of select="@name"/>
+          <xsl:for-each select="input/param[@type!='']">
+         * @param <xsl:value-of select="@name"></xsl:value-of><xsl:text>
+         </xsl:text></xsl:for-each>
+         */
+        public  void start<xsl:value-of select="@name"/>(
+         <xsl:variable name="paramCount"><xsl:value-of select="count(input/param[@type!=''])"></xsl:value-of></xsl:variable>
+         <xsl:for-each select="input/param[@type!='']">
+            <xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@type"/><xsl:text> </xsl:text><xsl:value-of select="@name"></xsl:value-of></xsl:for-each>
+            <xsl:if test="$paramCount>0">,</xsl:if>final <xsl:value-of select="$package"/>.<xsl:value-of select="$callbackname"/> callback) throws java.rmi.RemoteException{
+
+             org.apache.axis2.clientapi.Call _call = new org.apache.axis2.clientapi.Call(_serviceContext);
+ 		     org.apache.axis2.context.MessageContext _messageContext = getMessageContext();
+            _call.setTo(this.toEPR);
+            _call.setSoapAction("<xsl:value-of select="$soapAction"/>");
+            <xsl:for-each select="input/param[@Action!='']">_messageContext.setWSAAction("<xsl:value-of select="@Action"/>");</xsl:for-each>
+
+             org.apache.axis2.soap.SOAPEnvelope env = createEnvelope();
+             <xsl:choose>
+             <!-- There are more than 1 parameter in the input-->
+              <xsl:when test="$paramCount>0">
+              <xsl:choose>
+               <xsl:when test="$style='rpc'">
+           // Style is RPC
+           setValueRPC(env,
+            "<xsl:value-of select="@namespace"/>",
+            "<xsl:value-of select="@name"/>",
+             new String[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if>"<xsl:value-of select="@name"/>"</xsl:for-each>},
+             new Object[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@name"/></xsl:for-each>});
+                      </xsl:when>
+
+                      <xsl:when test="$style='doc'">
+           //Style is Doc
+            setValueDoc(env,<xsl:value-of select="$fullsupporterclassname"/>.toOM(<xsl:value-of select="input/param[1]/@name"/>));
+                      </xsl:when>
+                      <xsl:otherwise>
+          //Unknown style!! No code is generated
+          throw UnsupportedOperationException("Unknown Style");
+                      </xsl:otherwise>
+                  </xsl:choose>
+              </xsl:when>
+              <xsl:otherwise>
+                   <xsl:choose>
+                   <xsl:when test="$style='rpc'">
+           //Style is RPC. No input parameters
+              setValueRPC(env,
+                "<xsl:value-of select="@namespace"/>",
+                "<xsl:value-of select="@name"/>",
+                null,
+                null);
+                      </xsl:when>
+                      <!-- The follwing code is specific to XML beans-->
+                      <xsl:when test="$style='doc'">
+           //Style is Doc. No input parameters
+           setValueDoc(env,null);
+                      </xsl:when>
+                      <xsl:otherwise>
+          //Unknown style!! No code is generated
+          throw UnsupportedOperationException("Unknown Style");
+                      </xsl:otherwise>
+                  </xsl:choose>
+              </xsl:otherwise>
+            </xsl:choose>
+             _messageContext.setEnvelope(env);
+             <xsl:choose>
+             <xsl:when test="$outputtype=''">
+              //Nothing to pass as the callback!!!
+              _call.invokeNonBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext,null);
+              </xsl:when>
+              <xsl:otherwise>
+               _call.invokeNonBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext, new org.apache.axis2.clientapi.Callback(){
+                public void onComplete(org.apache.axis2.clientapi.AsyncResult result){
+
+			    java.lang.Object object = <xsl:value-of select="$fullsupporterclassname"/>.fromOM(getElement(result.getResponseEnvelope(),"<xsl:value-of select="$style"/>"),<xsl:value-of select="$outputtype"/>.class);
+                             callback.receiveResult<xsl:value-of select="@name"/>((<xsl:value-of select="$outputtype"/>)object);
+                }
+                public void reportError(java.lang.Exception e){
+                      callback.receiveError<xsl:value-of select="@name"/>(e);
+                }
+             }
+            );
+              </xsl:otherwise>
+             </xsl:choose>
+        }
+      </xsl:if>
+      <!-- End of in-out mep -->
+      </xsl:if>
+      <!-- Start of in only mep-->
+      <xsl:if test="$mep='http://www.w3.org/2004/08/wsdl/in-only'">
+      <!-- for the in only mep there is no notion of sync or async. And there is no return type also -->
+      public void <xsl:text> </xsl:text><xsl:value-of select="@name"/>(
+         <xsl:for-each select="input/param[@type!='']">
+            <xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@type"/><xsl:text> </xsl:text><xsl:value-of select="@name"/>
+         </xsl:for-each>) throws java.rmi.RemoteException{
+         org.apache.axis2.clientapi.Call _call = new org.apache.axis2.clientapi.Call(_serviceContext);
+            _call.setTransportInfo(this.senderTransport,this.listenerTransport,this.useSeparateListener);
+            
+ 		    org.apache.axis2.context.MessageContext _messageContext = getMessageContext();
+            _call.setTo(this.toEPR);
+            _call.setSoapAction("<xsl:value-of select="$soapAction"/>");
+            <xsl:for-each select="input/param[@Action!='']">_messageContext.setWSAAction("<xsl:value-of select="@Action"/>");</xsl:for-each>
+
+          org.apache.axis2.soap.SOAPEnvelope env = null;
+            env = createEnvelope();
+            <xsl:choose>
+            <!-- test the number of input parameters
+				  If the number of parameter is more then just run the normal generation-->
+              <xsl:when test="count(input/param[@type!=''])>0">
+                  <xsl:choose>
+                      <xsl:when test="$style='rpc'">
+               // Style is RPC
+              setValueRPC(env,"<xsl:value-of select="@namespace"/>","<xsl:value-of select="@name"/>",
+              new String[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if>"<xsl:value-of select="@name"/>"</xsl:for-each>},
+              new Object[]{<xsl:for-each select="input/param[@type!='']"><xsl:if test="position()>1">,</xsl:if><xsl:value-of select="@name"/></xsl:for-each>});
+                      </xsl:when>
+                      <xsl:when test="$style='doc'">
+                      <!-- for the doc lit case there can be only one element. So take the first element -->
+               //Style is Doc.
+               setValueDoc(env,<xsl:value-of select="$fullsupporterclassname"/>.toOM(<xsl:value-of select="input/param[1]/@name"/>));
+                      </xsl:when>
+                      <xsl:otherwise>
+               //Unknown style!! No code is generated
+               throw java.lang.UnsupportedOperationException("Unknown Style");
+                      </xsl:otherwise>
+                  </xsl:choose>
+              </xsl:when>
+              <!-- No input parameters present. So generate assuming no input parameters-->
+              <xsl:otherwise>
+                   <xsl:choose>
+                   <xsl:when test="$style='rpc'">
+               //Style is RPC. No input parameters
+               setValueRPC(env,"<xsl:value-of select="@namespace"/>","<xsl:value-of select="@name"/>",null,null);
+                      </xsl:when>
+                     <xsl:when test="$style='doc'">
+               //Style is Doc. No input parameters
+               setValueDoc(env,null);
+                      </xsl:when>
+                      <xsl:otherwise>
+             //Unknown style!! No code is generated
+              throw UnsupportedOperationException("Unknown Style");
+                      </xsl:otherwise>
+                  </xsl:choose>
+             </xsl:otherwise>
+            </xsl:choose>
+             _messageContext.setEnvelope(env);
+             _call.invokeBlocking(_operations[<xsl:value-of select="position()-1"/>], _messageContext);
+               return;
+          }
+      </xsl:if>
+     </xsl:for-each>
+    }
+    </xsl:template>
  </xsl:stylesheet>

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/LocalTestClassTemplate.xsl
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/LocalTestClassTemplate.xsl?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/LocalTestClassTemplate.xsl (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/LocalTestClassTemplate.xsl Tue Oct 25 21:29:17 2005
@@ -19,7 +19,7 @@
 	
 	import org.apache.axis2.context.ConfigurationContext;
 	import org.apache.axis2.deployment.DeploymentEngine;
-	import org.apache.axis2.description.ServiceDescription;
+	import org.apache.axis2.description.AxisService;
 	import org.apache.axis2.engine.AxisConfiguration;
 	import org.apache.axis2.wsdl.codegen.Constants;
 	import org.apache.axis2.om.OMAbstractFactory;
@@ -50,8 +50,8 @@
 			ClassLoader cl = Thread.currentThread().getContextClassLoader();
 			InputStream in = cl
 					.getResourceAsStream("<xsl:value-of select="$servicexmlpath"/>");
-			ServiceDescription service = new ServiceDescription();
-			deploymentEngine.buildService(service, in, classLoader);
+			AxisService axisService = new AxisService();
+			deploymentEngine.buildService(axisService, in, classLoader);
 			
 			ConfigurationContext configurationContext = new ConfigurationContext(
 					axisConfig);

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/MessageReceiverTemplate.xsl
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/MessageReceiverTemplate.xsl?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/MessageReceiverTemplate.xsl (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/MessageReceiverTemplate.xsl Tue Oct 25 21:29:17 2005
@@ -26,8 +26,8 @@
         <xsl:value-of select="$skeletonname"/> skel = (<xsl:value-of select="$skeletonname"/>)obj;
         //Out Envelop
         org.apache.axis2.soap.SOAPEnvelope envelope = null;
-        //Find the operation that has been set by the Dispatch phase.
-        org.apache.axis2.description.OperationDescription op = msgContext.getOperationContext().getOperationDescription();
+        //Find the axisOperation that has been set by the Dispatch phase.
+        org.apache.axis2.description.AxisOperation op = msgContext.getOperationContext().getAxisOperation();
         if (op == null) {
         throw new org.apache.axis2.AxisFault("Operation is not located, if this is doclit style the SOAP-ACTION should specified via the SOAP Action to use the RawXMLProvider");
         }
@@ -65,7 +65,7 @@
 
                             org.apache.axis2.om.OMElement firstChild = (org.apache.axis2.om.OMElement)msgContext.getEnvelope().getBody().getFirstChild();
                             if(null == firstChild)
-                            throw new org.apache.axis2.AxisFault("Wrapper Element Not Found for the operation of RPC style");
+                            throw new org.apache.axis2.AxisFault("Wrapper Element Not Found for the axisOperation of RPC style");
                             java.util.Iterator children = firstChild.getChildren();
                             org.apache.xmlbeans.XmlObject[] params = new org.apache.xmlbeans.XmlObject[<xsl:value-of select="$inputparamcount"/>];
                             int count = 0;

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/SkeletonTemplate.xsl
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/SkeletonTemplate.xsl?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/SkeletonTemplate.xsl (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/SkeletonTemplate.xsl Tue Oct 25 21:29:17 2005
@@ -3,7 +3,7 @@
     <xsl:template match="/interface">
     package <xsl:value-of select="@package"/>;
     /**
-     *  Auto generated java skeleton for the service by the Axis code generator
+     *  Auto generated java skeleton for the axisService by the Axis code generator
      */
     public class <xsl:value-of select="@name"></xsl:value-of> {
      <xsl:for-each select="method">

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestClassTemplate.xsl
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestClassTemplate.xsl?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestClassTemplate.xsl (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestClassTemplate.xsl Tue Oct 25 21:29:17 2005
@@ -18,7 +18,7 @@
 	
 	import org.apache.axis2.context.ConfigurationContext;
 	import org.apache.axis2.deployment.DeploymentEngine;
-	import org.apache.axis2.description.ServiceDescription;
+	import org.apache.axis2.description.AxisService;
 	import org.apache.axis2.engine.AxisConfiguration;
 	import org.apache.axis2.wsdl.codegen.Constants;
 	import org.apache.axis2.om.OMAbstractFactory;

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestSkeletonImplTemplate.xsl
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestSkeletonImplTemplate.xsl?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestSkeletonImplTemplate.xsl (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/TestSkeletonImplTemplate.xsl Tue Oct 25 21:29:17 2005
@@ -13,7 +13,7 @@
 		
 
     /**
-     *  Auto generated java skeleton for the service by the Axis code generator
+     *  Auto generated java skeleton for the axisService by the Axis code generator
      */
 
     public class <xsl:value-of select="@name"></xsl:value-of> extends <xsl:value-of select="@implpackage"/>.<xsl:value-of select="@servicename"></xsl:value-of>{

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/rpc/SimpleTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/rpc/SimpleTest.java?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/rpc/SimpleTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/rpc/SimpleTest.java Tue Oct 25 21:29:17 2005
@@ -24,10 +24,10 @@
 import org.apache.axis2.databinding.deserializers.SimpleDeserializerFactory;
 import org.apache.axis2.databinding.serializers.CollectionSerializer;
 import org.apache.axis2.databinding.serializers.SimpleSerializer;
-import org.apache.axis2.description.InOutOperationDescrition;
-import org.apache.axis2.description.OperationDescription;
+import org.apache.axis2.description.AxisOperation;
+import org.apache.axis2.description.AxisService;
+import org.apache.axis2.description.InOutAxisOperation;
 import org.apache.axis2.description.ParameterImpl;
-import org.apache.axis2.description.ServiceDescription;
 import org.apache.axis2.description.TransportInDescription;
 import org.apache.axis2.description.TransportOutDescription;
 import org.apache.axis2.engine.AxisConfigurationImpl;
@@ -45,7 +45,7 @@
  * SimpleTest
  */
 public class SimpleTest extends TestCase {
-    private ServiceDescription service;
+    private AxisService service;
 
     /**
      * Here's our test service which we'll be calling with the local transport
@@ -150,14 +150,14 @@
 
         LocalTransportReceiver.CONFIG_CONTEXT = new ConfigurationContext(config);
 
-        service = new ServiceDescription(new QName("testService"));
+        service = new AxisService(new QName("testService"));
         service.addParameter(
                 new ParameterImpl(AbstractMessageReceiver.SERVICE_CLASS,
                         Test.class.getName()));
-        OperationDescription operation = new InOutOperationDescrition(new QName(methodName));
-        operation.setMessageReceiver(new RPCInOutMessageReceiver());
-        operation.getMetadataBag().put(RPCInOutMessageReceiver.RPCMETHOD_PROPERTY, method);
-        service.addOperation(operation);
+        AxisOperation axisOperation = new InOutAxisOperation(new QName(methodName));
+        axisOperation.setMessageReceiver(new RPCInOutMessageReceiver());
+        axisOperation.getMetadataBag().put(RPCInOutMessageReceiver.RPCMETHOD_PROPERTY, method);
+        service.addOperation(axisOperation);
         service.setClassLoader(Thread.currentThread().getContextClassLoader());
         LocalTransportReceiver.CONFIG_CONTEXT.getAxisConfiguration()
                 .addService(service);

Modified: webservices/axis2/trunk/java/modules/common/src/org/apache/axis2/i18n/resource.properties
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/common/src/org/apache/axis2/i18n/resource.properties?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/common/src/org/apache/axis2/i18n/resource.properties (original)
+++ webservices/axis2/trunk/java/modules/common/src/org/apache/axis2/i18n/resource.properties Tue Oct 25 21:29:17 2005
@@ -18,7 +18,7 @@
 invaliduser=Invalid user name
 invalidSOAPversion=Invalid SOAP URI. Axis2 only supports SOAP 1.1 and 1.2
 cannotInferTransport=Cannot infer transport information from the URL information provided
-cannotBeNullOperationDescription=Operation description can not be null
+cannotBeNullAxisOperation=Axis Operation can not be null
 cannotBeNullServiceContext=ServiceContext can not be null
 cannotBeNullConfigurationContext=ConfigurationContext can not be null
 cannotBeNullOperationContext=OperationContext can not be null

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/InstanceDispatcher.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/InstanceDispatcher.java?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/XMLBeans/XMLBeansSchemaUtility.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/databinding/extensions/XMLBeans/XMLBeansSchemaUtility.java Tue Oct 25 21:29:17 2005
@@ -11,8 +11,8 @@
 import com.ibm.wsdl.extensions.schema.SchemaImpl;
 import org.apache.axis2.AxisFault;
 import org.apache.axis2.databinding.extensions.SchemaUtility;
-import org.apache.axis2.description.OperationDescription;
-import org.apache.axis2.description.ServiceDescription;
+import org.apache.axis2.description.AxisOperation;
+import org.apache.axis2.description.AxisService;
 import org.apache.axis2.om.OMElement;
 import org.apache.axis2.om.impl.llom.builder.StAXOMBuilder;
 import org.apache.axis2.wsdl.codegen.extension.XMLBeansExtension;
@@ -67,10 +67,10 @@
     protected Log log = LogFactory.getLog(getClass());
     private Definition definition;
 
-    public boolean isRelevant(ServiceDescription serviceDescription) throws AxisFault {
+    public boolean isRelevant(AxisService axisService) throws AxisFault {
         try {
-            ClassLoader classLoader = serviceDescription.getClassLoader();
-            String serviceClassName = (String) serviceDescription.getParameter("ServiceClass").getValue();
+            ClassLoader classLoader = axisService.getClassLoader();
+            String serviceClassName = (String) axisService.getParameter("ServiceClass").getValue();
 
             Class serviceImplementation = classLoader.loadClass(serviceClassName);
 
@@ -91,35 +91,35 @@
             }
             return false;
         } catch (ClassNotFoundException e) {
-            log.error("Can not load the service " + serviceDescription + " from the given class loader");
+            log.error("Can not load the service " + axisService + " from the given class loader");
             throw new AxisFault(e);
         }
     }
 
-    public void fillInformationFromServiceDescription(ServiceDescription serviceDescription, Definition definition) throws AxisFault {
+    public void fillInformationFromAxisService(AxisService axisService, Definition definition) throws AxisFault {
         this.definition = definition;
 
         // first fill the schema information
-//        getSchema(serviceDescription);
+//        getSchema(axisService);
 
         // now fill port type and message elements
-        createMessagesAndPortTypes(serviceDescription);
+        createMessagesAndPortTypes(axisService);
     }
 
-    public Definition fillInformationFromServiceDescription(ServiceDescription serviceDescription) throws AxisFault {
+    public Definition fillInformationFromAxisService(AxisService axisService) throws AxisFault {
         this.definition = new DefinitionImpl();
-        this.fillInformationFromServiceDescription(serviceDescription, this.definition);
+        this.fillInformationFromAxisService(axisService, this.definition);
         return definition;
     }
 
-    private void getSchema(ServiceDescription serviceDescription) throws AxisFault {
-        if (!isRelevant(serviceDescription)) {
+    private void getSchema(AxisService axisService) throws AxisFault {
+        if (!isRelevant(axisService)) {
             return;
         }
 
 
         try {
-            File file = new File(serviceDescription.getFileName());
+            File file = new File(axisService.getFileName());
             ZipInputStream zipInputStream = new ZipInputStream(new FileInputStream(file));
 
             ZipEntry entry;
@@ -132,7 +132,7 @@
             while ((entry = zipInputStream.getNextEntry()) != null) {
                 entryName = entry.getName();
                 if (entryName.startsWith(XMLBeansExtension.SCHEMA_FOLDER) && entryName.endsWith(".xsd")) {
-                    InputStream schemaEntry = serviceDescription.getClassLoader().getResourceAsStream(entryName);
+                    InputStream schemaEntry = axisService.getClassLoader().getResourceAsStream(entryName);
                     schema = new SchemaImpl();
                     Document document = DocumentBuilderFactory.newInstance().newDocumentBuilder().parse(schemaEntry);
                     schema.setElement(document.getDocumentElement());
@@ -168,18 +168,18 @@
 
     }
 
-    private void createMessagesAndPortTypes(ServiceDescription serviceDescription) throws AxisFault {
+    private void createMessagesAndPortTypes(AxisService axisService) throws AxisFault {
 
-        HashMap mappings = readMappings(serviceDescription);
+        HashMap mappings = readMappings(axisService);
 
 
         try {
-            ClassLoader classLoader = serviceDescription.getClassLoader();
-            String serviceClassName = (String) serviceDescription.getParameter("ServiceClass").getValue();
+            ClassLoader classLoader = axisService.getClassLoader();
+            String serviceClassName = (String) axisService.getParameter("ServiceClass").getValue();
 
             // create PortType with class name
             PortType portType = new PortTypeImpl();
-            portType.setQName(serviceDescription.getName());
+            portType.setQName(axisService.getName());
             definition.addPortType(portType);
             portType.setUndefined(false);
 
@@ -191,13 +191,13 @@
             Input wsdlOperationInput;
             Output wsdlOperationOutput;
 
-            Iterator operationDescIter = serviceDescription.getOperations().values().iterator();
+            Iterator operationDescIter = axisService.getOperations().values().iterator();
             while (operationDescIter.hasNext()) {
-                OperationDescription operation = (OperationDescription) operationDescIter.next();
-                QName methodName = operation.getName();
+                AxisOperation axisOperation = (AxisOperation) operationDescIter.next();
+                QName methodName = axisOperation.getName();
                 Method method = getMethod(methods, methodName.getLocalPart());
 
-                // create operation
+                // create axisOperation
                 wsdlOperation = new OperationImpl();
                 wsdlOperation.setName(methodName.getLocalPart());
                 wsdlOperation.setUndefined(false);
@@ -207,7 +207,7 @@
                 Message message = getMessage(mappings, returnType);
                 definition.addMessage(message);
 
                 // add the same message as the output of the operation
                 wsdlOperationOutput = new OutputImpl();
                 wsdlOperationOutput.setMessage(message);
                 wsdlOperation.setOutput(wsdlOperationOutput);
@@ -226,7 +226,7 @@
 
 
         } catch (ClassNotFoundException e) {
-            log.error("Can not load the service " + serviceDescription + " from the given class loader");
+            log.error("Can not load the service " + axisService + " from the given class loader");
             throw new AxisFault(e);
         }
 
@@ -248,10 +248,10 @@
         return message;
     }
 
-    private HashMap readMappings(ServiceDescription serviceDescription) throws AxisFault {
+    private HashMap readMappings(AxisService axisService) throws AxisFault {
         HashMap mappings = new HashMap();
         try {
-            File file = new File(serviceDescription.getFileName());
+            File file = new File(axisService.getFileName());
             ZipInputStream zipInputStream = new ZipInputStream(new FileInputStream(file));
 
             ZipEntry entry;
@@ -259,7 +259,7 @@
             while ((entry = zipInputStream.getNextEntry()) != null) {
                 entryName = entry.getName();
                 if (entryName.startsWith(XMLBeansExtension.MAPPING_FOLDER) && entryName.endsWith(".xml")) {
-                    InputStream schemaEntry = serviceDescription.getClassLoader().getResourceAsStream(entryName);
+                    InputStream schemaEntry = axisService.getClassLoader().getResourceAsStream(entryName);
                     OMElement mappingsElement = new StAXOMBuilder(schemaEntry).getDocumentElement();
                     Iterator mappingElementsIter = mappingsElement.getChildElements();
                     while (mappingElementsIter.hasNext()) {
@@ -207,7 +207,7 @@
                 definition.addMessage(message);
 
-                // add the same message as the output of the operation
+                // add the same message as the output of the axisOperation
                 wsdlOperationOutput = new OutputImpl();
                 wsdlOperationOutput.setMessage(message);

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/RPCInOutMessageReceiver.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/RPCInOutMessageReceiver.java?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/receivers/RPCMessageReceiver.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/rpc/receivers/RPCMessageReceiver.java Tue Oct 25 21:29:17 2005
@@ -24,7 +24,7 @@
 
 import org.apache.axis2.AxisFault;
 import org.apache.axis2.context.MessageContext;
-import org.apache.axis2.description.OperationDescription;
+import org.apache.axis2.description.AxisOperation;
 import org.apache.axis2.engine.DependencyManager;
 import org.apache.axis2.om.OMAbstractFactory;
 import org.apache.axis2.om.OMElement;
@@ -76,14 +76,14 @@
             Class ImplClass = obj.getClass();
             DependencyManager.configureBusinessLogicProvider(obj, inMessage, null);
 
-            OperationDescription op = inMessage.getOperationContext().getOperationDescription();
+            AxisOperation op = inMessage.getOperationContext().getAxisOperation();
 
             OMElement methodElement = inMessage.getEnvelope().getBody()
                     .getFirstElement();
             String methodName = op.getName().getLocalPart();
             Method[] methods = ImplClass.getMethods();
             //todo method validation has to be done
             //Todo if we find the method it should be store , in OperationDescription
             for (int i = 0; i < methods.length; i++) {
                 if (methods[i].getName().equals(methodName)) {
                     this.method = methods[i];
@@ -96,7 +96,7 @@
             Object resObject = method.invoke(obj, objectArray);
 
             // Handling the response
             //todo NameSpace has to be taken from the serviceDescription
             OMNamespace ns = getSOAPFactory().createOMNamespace(
                     "http://soapenc/", "res");
             SOAPEnvelope envelope = getSOAPFactory().getDefaultEnvelope();
@@ -76,14 +76,14 @@
             Method[] methods = ImplClass.getMethods();
             //todo method validation has to be done
-            //Todo if we find the method it should be store , in OperationDescription
+            //Todo if we find the method it should be store , in AxisOperation
             for (int i = 0; i < methods.length; i++) {
                 if (methods[i].getName().equals(methodName)) {
@@ -96,7 +96,7 @@
 
             // Handling the response
-            //todo NameSpace has to be taken from the serviceDescription
+            //todo NameSpace has to be taken from the AxisService
             OMNamespace ns = getSOAPFactory().createOMNamespace(
                     "http://soapenc/", "res");

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/InterfaceImplementationTemplate.xsl
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/template/java/InterfaceImplementationTemplate.xsl?rev=328554&r1=328553&r2=328554&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/InstanceDispatcher.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/InstanceDispatcher.java Tue Oct 25 21:29:17 2005
@@ -18,17 +18,16 @@
 
 import org.apache.axis2.context.MessageContext;
 import org.apache.axis2.context.OperationContext;
-import org.apache.axis2.context.OperationContextFactory;
 import org.apache.axis2.context.ServiceContext;
 import org.apache.axis2.context.ServiceGroupContext;
-import org.apache.axis2.description.OperationDescription;
+import org.apache.axis2.description.AxisOperation;
 import org.apache.axis2.handlers.AbstractHandler;
 
 public class InstanceDispatcher extends AbstractHandler {
     /**
      * By the time the control comes to this handler the dispatching must have happened
      * so that the message context contains the ServiceGroupDescription, ServiceDescription and
      * OperationDescription.
      * This will then try to find the Contexts of ServiceGroup, Service and the Operation.
      */
 
@@ -46,14 +45,14 @@
             return;
         }
 
-        OperationDescription operationDesc = msgContext.getOperationDescription();
+        AxisOperation axisOperation = msgContext.getAxisOperation();
 
         //  1. look up opCtxt using mc.addressingHeaders.relatesTo[0]
-        OperationContext operationContext = operationDesc.findForExistingOperationContext(msgContext);
+        OperationContext operationContext = axisOperation.findForExistingOperationContext(msgContext);
 
         if (operationContext != null) {
             // register operation context and message context
-            operationDesc.registerOperationContext(msgContext, operationContext);
+            axisOperation.registerOperationContext(msgContext, operationContext);
             ServiceContext serviceContext = (ServiceContext) operationContext.getParent();
             ServiceGroupContext serviceGroupContext = (ServiceGroupContext) serviceContext.getParent();
             msgContext.setServiceContext(serviceContext);
@@ -62,9 +61,9 @@
             return;
 
         } else { //  2. if null, create new opCtxt
-            operationContext =new OperationContext(operationDesc);
-//            operationContext = OperationContextFactory.createOperationContext(operationDesc.getAxisSpecifMEPConstant(), operationDesc);
-            operationDesc.registerOperationContext(msgContext, operationContext);
+            operationContext =new OperationContext(axisOperation);
+//            operationContext = OperationContextFactory.createOperationContext(axisOperation.getAxisSpecifMEPConstant(), axisOperation);
+            axisOperation.registerOperationContext(msgContext, operationContext);
 
             //  fill the service group context and service context info
             msgContext.getSystemContext().
@@ -18,17 +18,16 @@
     /**
      * By the time the control comes to this handler the dispatching must have happened
-     * so that the message context contains the ServiceGroupDescription, ServiceDescription and
-     * OperationDescription.
+     * so that the message context contains the AxisServiceGroup, AxisService and
+     * AxisOperation.
      * This will then try to find the Contexts of ServiceGroup, Service and the Operation.
      */